"use strict";

var helpers = require("../../../helpers/helpers");

exports["America/Indiana/Petersburg"] = {

	"guess:by:offset" : helpers.makeTestGuess("America/Indiana/Petersburg", { offset: true, expect: "America/New_York" }),

	"guess:by:abbr" : helpers.makeTestGuess("America/Indiana/Petersburg", { abbr: true, expect: "America/New_York" }),

	"1918" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1918-03-31T07:59:59+00:00", "01:59:59", "CST", 360],
		["1918-03-31T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1918-10-27T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1918-10-27T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1919" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1919-03-30T07:59:59+00:00", "01:59:59", "CST", 360],
		["1919-03-30T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1919-10-26T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1919-10-26T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1942" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1942-02-09T07:59:59+00:00", "01:59:59", "CST", 360],
		["1942-02-09T08:00:00+00:00", "03:00:00", "CWT", 300]
	]),

	"1945" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1945-08-14T22:59:59+00:00", "17:59:59", "CWT", 300],
		["1945-08-14T23:00:00+00:00", "18:00:00", "CPT", 300],
		["1945-09-30T06:59:59+00:00", "01:59:59", "CPT", 300],
		["1945-09-30T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1955" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1955-05-01T05:59:59+00:00", "23:59:59", "CST", 360],
		["1955-05-01T06:00:00+00:00", "01:00:00", "CDT", 300],
		["1955-09-25T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1955-09-25T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1956" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1956-04-29T07:59:59+00:00", "01:59:59", "CST", 360],
		["1956-04-29T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1956-09-30T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1956-09-30T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1957" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1957-04-28T07:59:59+00:00", "01:59:59", "CST", 360],
		["1957-04-28T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1957-09-29T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1957-09-29T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1958" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1958-04-27T07:59:59+00:00", "01:59:59", "CST", 360],
		["1958-04-27T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1958-09-28T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1958-09-28T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1959" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1959-04-26T07:59:59+00:00", "01:59:59", "CST", 360],
		["1959-04-26T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1959-09-27T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1959-09-27T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1960" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1960-04-24T07:59:59+00:00", "01:59:59", "CST", 360],
		["1960-04-24T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1960-09-25T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1960-09-25T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1961" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1961-04-30T07:59:59+00:00", "01:59:59", "CST", 360],
		["1961-04-30T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1961-10-29T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1961-10-29T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1962" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1962-04-29T07:59:59+00:00", "01:59:59", "CST", 360],
		["1962-04-29T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1962-10-28T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1962-10-28T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1963" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1963-04-28T07:59:59+00:00", "01:59:59", "CST", 360],
		["1963-04-28T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1963-10-27T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1963-10-27T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1964" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1964-04-26T07:59:59+00:00", "01:59:59", "CST", 360],
		["1964-04-26T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1964-10-25T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1964-10-25T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1965" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1965-04-25T07:59:59+00:00", "01:59:59", "CST", 360],
		["1965-04-25T08:00:00+00:00", "03:00:00", "EST", 300]
	]),

	"1966" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1966-10-30T06:59:59+00:00", "01:59:59", "EST", 300],
		["1966-10-30T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1967" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1967-04-30T07:59:59+00:00", "01:59:59", "CST", 360],
		["1967-04-30T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1967-10-29T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1967-10-29T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1968" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1968-04-28T07:59:59+00:00", "01:59:59", "CST", 360],
		["1968-04-28T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1968-10-27T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1968-10-27T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1969" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1969-04-27T07:59:59+00:00", "01:59:59", "CST", 360],
		["1969-04-27T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1969-10-26T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1969-10-26T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1970" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1970-04-26T07:59:59+00:00", "01:59:59", "CST", 360],
		["1970-04-26T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1970-10-25T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1970-10-25T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1971" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1971-04-25T07:59:59+00:00", "01:59:59", "CST", 360],
		["1971-04-25T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1971-10-31T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1971-10-31T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1972" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1972-04-30T07:59:59+00:00", "01:59:59", "CST", 360],
		["1972-04-30T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1972-10-29T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1972-10-29T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1973" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1973-04-29T07:59:59+00:00", "01:59:59", "CST", 360],
		["1973-04-29T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1973-10-28T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1973-10-28T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1974" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1974-01-06T07:59:59+00:00", "01:59:59", "CST", 360],
		["1974-01-06T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1974-10-27T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1974-10-27T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1975" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1975-02-23T07:59:59+00:00", "01:59:59", "CST", 360],
		["1975-02-23T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1975-10-26T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1975-10-26T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1976" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1976-04-25T07:59:59+00:00", "01:59:59", "CST", 360],
		["1976-04-25T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1976-10-31T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1976-10-31T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"1977" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["1977-04-24T07:59:59+00:00", "01:59:59", "CST", 360],
		["1977-04-24T08:00:00+00:00", "03:00:00", "CDT", 300],
		["1977-10-30T06:59:59+00:00", "01:59:59", "CDT", 300],
		["1977-10-30T07:00:00+00:00", "02:00:00", "EST", 300]
	]),

	"2006" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2006-04-02T06:59:59+00:00", "01:59:59", "EST", 300],
		["2006-04-02T07:00:00+00:00", "02:00:00", "CDT", 300],
		["2006-10-29T06:59:59+00:00", "01:59:59", "CDT", 300],
		["2006-10-29T07:00:00+00:00", "01:00:00", "CST", 360]
	]),

	"2007" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2007-03-11T07:59:59+00:00", "01:59:59", "CST", 360],
		["2007-03-11T08:00:00+00:00", "03:00:00", "CDT", 300],
		["2007-11-04T06:59:59+00:00", "01:59:59", "CDT", 300],
		["2007-11-04T07:00:00+00:00", "02:00:00", "EST", 300]
	]),

	"2008" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2008-03-09T06:59:59+00:00", "01:59:59", "EST", 300],
		["2008-03-09T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2008-11-02T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2008-11-02T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2009" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2009-03-08T06:59:59+00:00", "01:59:59", "EST", 300],
		["2009-03-08T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2009-11-01T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2009-11-01T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2010" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2010-03-14T06:59:59+00:00", "01:59:59", "EST", 300],
		["2010-03-14T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2010-11-07T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2010-11-07T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2011" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2011-03-13T06:59:59+00:00", "01:59:59", "EST", 300],
		["2011-03-13T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2011-11-06T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2011-11-06T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2012" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2012-03-11T06:59:59+00:00", "01:59:59", "EST", 300],
		["2012-03-11T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2012-11-04T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2012-11-04T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2013" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2013-03-10T06:59:59+00:00", "01:59:59", "EST", 300],
		["2013-03-10T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2013-11-03T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2013-11-03T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2014" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2014-03-09T06:59:59+00:00", "01:59:59", "EST", 300],
		["2014-03-09T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2014-11-02T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2014-11-02T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2015" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2015-03-08T06:59:59+00:00", "01:59:59", "EST", 300],
		["2015-03-08T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2015-11-01T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2015-11-01T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2016" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2016-03-13T06:59:59+00:00", "01:59:59", "EST", 300],
		["2016-03-13T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2016-11-06T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2016-11-06T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2017" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2017-03-12T06:59:59+00:00", "01:59:59", "EST", 300],
		["2017-03-12T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2017-11-05T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2017-11-05T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2018" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2018-03-11T06:59:59+00:00", "01:59:59", "EST", 300],
		["2018-03-11T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2018-11-04T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2018-11-04T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2019" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2019-03-10T06:59:59+00:00", "01:59:59", "EST", 300],
		["2019-03-10T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2019-11-03T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2019-11-03T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2020" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2020-03-08T06:59:59+00:00", "01:59:59", "EST", 300],
		["2020-03-08T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2020-11-01T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2020-11-01T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2021" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2021-03-14T06:59:59+00:00", "01:59:59", "EST", 300],
		["2021-03-14T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2021-11-07T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2021-11-07T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2022" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2022-03-13T06:59:59+00:00", "01:59:59", "EST", 300],
		["2022-03-13T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2022-11-06T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2022-11-06T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2023" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2023-03-12T06:59:59+00:00", "01:59:59", "EST", 300],
		["2023-03-12T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2023-11-05T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2023-11-05T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2024" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2024-03-10T06:59:59+00:00", "01:59:59", "EST", 300],
		["2024-03-10T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2024-11-03T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2024-11-03T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2025" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2025-03-09T06:59:59+00:00", "01:59:59", "EST", 300],
		["2025-03-09T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2025-11-02T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2025-11-02T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2026" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2026-03-08T06:59:59+00:00", "01:59:59", "EST", 300],
		["2026-03-08T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2026-11-01T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2026-11-01T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2027" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2027-03-14T06:59:59+00:00", "01:59:59", "EST", 300],
		["2027-03-14T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2027-11-07T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2027-11-07T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2028" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2028-03-12T06:59:59+00:00", "01:59:59", "EST", 300],
		["2028-03-12T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2028-11-05T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2028-11-05T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2029" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2029-03-11T06:59:59+00:00", "01:59:59", "EST", 300],
		["2029-03-11T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2029-11-04T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2029-11-04T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2030" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2030-03-10T06:59:59+00:00", "01:59:59", "EST", 300],
		["2030-03-10T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2030-11-03T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2030-11-03T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2031" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2031-03-09T06:59:59+00:00", "01:59:59", "EST", 300],
		["2031-03-09T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2031-11-02T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2031-11-02T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2032" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2032-03-14T06:59:59+00:00", "01:59:59", "EST", 300],
		["2032-03-14T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2032-11-07T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2032-11-07T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2033" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2033-03-13T06:59:59+00:00", "01:59:59", "EST", 300],
		["2033-03-13T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2033-11-06T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2033-11-06T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2034" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2034-03-12T06:59:59+00:00", "01:59:59", "EST", 300],
		["2034-03-12T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2034-11-05T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2034-11-05T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2035" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2035-03-11T06:59:59+00:00", "01:59:59", "EST", 300],
		["2035-03-11T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2035-11-04T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2035-11-04T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2036" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2036-03-09T06:59:59+00:00", "01:59:59", "EST", 300],
		["2036-03-09T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2036-11-02T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2036-11-02T06:00:00+00:00", "01:00:00", "EST", 300]
	]),

	"2037" : helpers.makeTestYear("America/Indiana/Petersburg", [
		["2037-03-08T06:59:59+00:00", "01:59:59", "EST", 300],
		["2037-03-08T07:00:00+00:00", "03:00:00", "EDT", 240],
		["2037-11-01T05:59:59+00:00", "01:59:59", "EDT", 240],
		["2037-11-01T06:00:00+00:00", "01:00:00", "EST", 300]
	])
};